
# Slot: is_class_field


indicates that any instance, i,  the domain of this slot will include an assert of i s range

URI: [linkml:is_class_field](https://w3id.org/linkml/is_class_field)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [Boolean](Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
